
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.8.3',
    'branch_nick': '(no',
    'revision_id': '583622376e8489288edcad7bedb4986f67bcf251',
    'revno': 4482
}
